# analytics-logger-rest
REST analytics logger

To use this package simply install and then

`import analytics_logger_rest.analytics_logger_rest as log_rest`

`logger = log_rest.LogAnalyticsLogger("NAME")`

Built with help from here https://docs.microsoft.com/en-us/azure/azure-monitor/logs/data-collector-api
